@@ -4,15 +4,15 @@ test_that("get_anchor returns data object", {
 })
 
 
-test_that("test_anchor", {
+test_that("test_anchor, pairdir", {
 
     df_anchors <- data.frame(
         a = c("rest", "rested", "stay", "stand"),
         z = c("coming", "embarked", "fast", "move")
     )
 
-    test_anch1 <- test_anchors(df_anchors, ft_wv_sample)
-    test_anch2 <- test_anchors(df_anchors, ft_wv_sample, all = TRUE)
+    test_anch1 <- test_anchors(df_anchors, ft_wv_sample, method = "pairdir")
+    test_anch2 <- test_anchors(df_anchors, ft_wv_sample, method = "pairdir", all = TRUE)
 
     expect_type(test_anch1, "list")
     expect_s3_class(test_anch1, "data.frame")
@@ -24,6 +24,65 @@ test_that("test_anchor", {
 
 })
 
+
+
+test_that("test_anchor, pairdir", {
+
+    df_anchors <- data.frame(
+        a = c("rest", "rested", "stay", "stand"),
+        z = c("coming", "embarked", "fast", "move")
+    )
+    non_anchors <- c("writ", "alloys", "ills", "atlas", "saturn", "cape", "unfolds")
+
+    test_anch1 <- test_anchors(df_anchors[, 1], ft_wv_sample, method = "relco", 
+                               type = "centroid", non_anchors = non_anchors)
+    test_anch2 <- test_anchors(df_anchors$a, ft_wv_sample, method = "relco", 
+                               type = "compound", non_anchors = non_anchors)
+    test_anch3 <- test_anchors(df_anchors, ft_wv_sample, method = "relco", 
+                               type = "direction", dir_method = "paired", 
+                               non_anchors = non_anchors)
+    test_anch4 <- test_anchors(df_anchors, ft_wv_sample, method = "relco", 
+                               type = "direction", dir_method = "pooled", 
+                               non_anchors = non_anchors, seed = 18015)
+    test_anch5 <- test_anchors(df_anchors, ft_wv_sample, method = "relco", 
+                               type = "direction", dir_method = "pooled", 
+                               non_anchors = non_anchors, seed = 18015, )
+    expect_type(test_anch1, "list")
+    expect_s3_class(test_anch1, "data.frame")
+    expect_identical(dim(test_anch1), c(4L, 4L))
+
+    expect_type(test_anch2, "list")
+    expect_s3_class(test_anch2, "data.frame")
+    expect_identical(dim(test_anch2), c(4L, 4L))
+
+    expect_type(test_anch3, "list")
+    expect_s3_class(test_anch3, "data.frame")
+    expect_identical(dim(test_anch3), c(8L, 5L))
+
+    expect_type(test_anch4, "list")
+    expect_s3_class(test_anch4, "data.frame")
+    expect_identical(dim(test_anch4), c(8L, 5L))
+
+    expect_no_error(capture_output(print(test_anch1)))
+    expect_no_error(capture_output(print(test_anch3)))
+
+    df_error <- cbind(df_anchors, df_anchors)
+    non_anchors_errors1 <- 1:4
+    non_anchors_errors2 <- c(non_anchors, "stand")
+
+    expect_error(test_anchors(df, ft_wv_sample, method = "relco", 
+                              type = "centroid", non_anchors = non_anchors))
+    expect_error(test_anchors(df, ft_wv_sample, method = "relco", 
+                              type = "direction", non_anchors = non_anchors))
+    expect_error(test_anchors(df_anchors, ft_wv_sample, method = "relco", 
+                              type = "direction", non_anchors = non_anchors_errors1))
+    expect_error(test_anchors(df_anchors, ft_wv_sample, method = "relco", 
+                              type = "direction", non_anchors = non_anchors_errors2))
+    
+    
+    
+})
+
 test_that("get_centroid works on different data types", {
     ## single c() list of terms ##
     out.c <- get_centroid(
